Index: runtime/observatory/tests/service/positive_token_pos_test.dart |
diff --git a/runtime/observatory/tests/service/positive_token_pos_test.dart b/runtime/observatory/tests/service/positive_token_pos_test.dart |
index 05ef175d4b001e7ac54fad47c02799de0acb3d8c..c30da31d28dabe0a6bc81c64eaaf0189ea2d9dc5 100644 |
--- a/runtime/observatory/tests/service/positive_token_pos_test.dart |
+++ b/runtime/observatory/tests/service/positive_token_pos_test.dart |
@@ -9,20 +9,20 @@ import 'package:unittest/unittest.dart'; |
import 'service_test_common.dart'; |
import 'test_helper.dart'; |
-helper() async { |
- // Line 12, Col 16 is the open brace. |
+helper() async { // Line 12, Col 16 is the open brace. |
} |
testMain() { |
debugger(); |
- helper(); // Line 18, Col 3 is the position of the function call. |
+ helper(); // Line 17, Col 3 is the position of the function call. |
} |
var tests = [ |
hasStoppedAtBreakpoint, |
markDartColonLibrariesDebuggable, |
- stoppedAtLine(18), |
+ stoppedAtLine(17), |
stepInto, |
+ |
(Isolate isolate) async { |
ServiceMap stack = await isolate.getStack(); |
expect(stack['frames'].length, greaterThan(3)); |
@@ -41,7 +41,7 @@ var tests = [ |
frame = stack['frames'][2]; |
expect(frame.function.name, equals('testMain')); |
- expect(await frame.location.getLine(), equals(18)); |
+ expect(await frame.location.getLine(), equals(17)); |
expect(await frame.location.getColumn(), equals(3)); |
} |
]; |